@@ -38,9 +38,10 @@ def add_tasks_and_process_time_middleware(new_app):
         g.app = new_app
         print("url path", request.url.path, "***url", request.url)
         context = request.scope['aws.context']
-        print('context', context)
-        print('contect_dict', context.__dict__)
-        print('sls sdk', context.serverless_sdk)
+        print('context1', context)
+        print('contect_dict1', context.__dict__)
+        print('sls sdk1', context.serverless_sdk)
+        context.serverless_sdk.set_endpoint(request.url.path)
         response = await call_next(request)
         if response.status_code == 404 and g.settings.save_calls:
             await save_not_found_from_request(request)
